# pip install bs4 lxml requests

import base64
import sys
from pathlib import Path

import requests
from bs4 import BeautifulSoup

headers = {
    "user-agent": "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/106.0.0.0 "
                  "YaBrowser/22.11.3.838 Yowser/2.5 Safari/537.36",
    "accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,"
              "application/signed-exchange;v=b3;q=0.9"
}


def get_img(url: str) -> (str, bool):
    """
    Получение текста html-страницы.
    :param url: Ссылка на страницу.
    :return: Текст страницы или False в случае исключения.
    """
    try:
        rs = requests.get(url=url, headers=headers)
        if rs.status_code == 200:
            return rs.text
        return False
    except Exception:
        return False


def finder_base64_img(txt: str):
    """
    Поиск всех тегов "img"; проверка, является ли содержимое
    данного тега base64-изображением; декодирование изображения;
    сохранение в файл.
    :param txt: Текст html-страницы.
    """
    soup = BeautifulSoup(txt, "lxml")
    for num, img in enumerate(soup.find_all("img")):
        if img.get('src').split(",")[0].split(";")[0].split("/")[1] in ["png", "jpg", "jpeg", "gif", "webp"]:
            ext = img.get('src').split(",")[0].split(";")[0].split("/")[1]
            try:
                name = img.get('alt') if img.get('alt') else "image"
            except AttributeError:
                name = "image"
            img = img.get('src').split(",")[1].encode()

            with open(Path.cwd() / f'{name}{num}.{ext}', 'wb') as file:
                file.write(base64.decodebytes(img))


def main():
    """
    Обработка пользовательского ввода.
    """
    # https://www.websiteoptimization.com/speed/tweak/inline-images/folder-test.html
    path = input("Введите ссылку на страницу с изображениями base64: ")
    if path.startswith("http"):
        if txt := get_img(path):
            finder_base64_img(txt)
        else:
            print("Не удалось получить текст страницы")
            sys.exit(0)
    else:
        print("Введенная строка не является адресом")


if __name__ == "__main__":
    main()
